@@ -1,7 +1,7 @@
 from torch.optim import Adam
 from all.agents import VSarsa
 from all.approximation import QNetwork
-from all.policies import GreedyPolicy
+from all.policies import ParallelGreedyPolicy
 from all.logging import DummyWriter
 from .models import fc_relu_q
 
@@ -15,7 +15,9 @@ def vsarsa(
         # Exploration settings
         epsilon=0.1,
         # Parallel actors
-        n_envs=1,
+        n_envs=8,
+        # Model construction
+        model_constructor=fc_relu_q
 ):
     """
     Vanilla SARSA classic control preset.
@@ -27,13 +29,14 @@ def vsarsa(
         eps (float): Stability parameters for the Adam optimizer.
         epsilon (int): Probability of choosing a random action.
         n_envs (int): Number of parallel environments.
+        model_constructor (function): The function used to construct the neural model.
     """
     def _vsarsa(envs, writer=DummyWriter()):
         env = envs[0]
-        model = fc_relu_q(env).to(device)
+        model = model_constructor(env).to(device)
         optimizer = Adam(model.parameters(), lr=lr, eps=eps)
         q = QNetwork(model, optimizer, writer=writer)
-        policy = GreedyPolicy(q, env.action_space.n, epsilon=epsilon)
+        policy = ParallelGreedyPolicy(q, env.action_space.n, epsilon=epsilon)
         return VSarsa(q, policy, discount_factor=discount_factor)
     return _vsarsa, n_envs
  
\ No newline at end of file
